#!/bin/bash

############################################################################
#
# MODULE:       GUI
# AUTHOR(S):    CacheGuard Development Team
# COPYRIGHT:    (C) 2009-2020 by CacheGuard Technologies Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
###########################################################################

# Main()

require-cert-checked()
{
    if test -f /tmp/${LDAP_CA}.2del ; then
	return 1
    elif test -s ${SSL_DIR}/${LDAP_CA} -o -s /tmp/${LOADED}.${LDAP_CA} ; then
	echo -n checked
	return 0
    else
	return 1
    fi
}

require-cert-boolean()
{
    if test -f /tmp/${LDAP_CA}.2del ; then
	echo -n 1
    elif test -s ${SSL_DIR}/${LDAP_CA} -o -s /tmp/${LOADED}.${LDAP_CA} ; then
	echo -n 0
    else
	echo -n 1
    fi
}

show-authenticate-ldap-cert-form()
{
    local left=40
    local right=60
    local length=3

    local hide=$(require-cert-boolean)

    show-title "LDAPS CA Certificate" "enabled" "authenticate"
    echo "<div class='core-form'>"
    show-form-begin ${length}

    echo "<table>"
    echo "<tr>"
    echo "<td width='5%'><input id='require_cert' name='require_cert' type='checkbox' $(require-cert-checked) onClick=\"collapseCheckZone( 'require_cert', 'loadcacert', 0 )\"></td><td width='95%'><span class='table-title'>Requires CA Certificate</span></td>"
    echo "</tr>"
    echo "</table>"

    if test ${hide} -eq 0 ; then
        local display=inline
    else
        local display=none
    fi

    echo "<div id='loadcacert' style='float:left;display:${display};'>"
    echo "<span class='shortcut-menu-item' style='margin:0; margin-top:10px;'><a href='access-file.${GUI_EXT_NAME}'>File Servers</a></span>"
    echo "<div style='clear:left;'></div>"
    echo "<table class='highlight-form'>"
    echo "<tr>"
    echo "<td width='${left}%'>Protocol</td>"
    echo "<td width='${right}%'>"
    show-file-protocol ${VALUES[1]:1}
    echo "</td>"
    echo "</tr>"

    echo "<tr>"
    echo "<td width=${left}%>File Server</td>"
    echo "<td width=${right}%>"
    show-file-servers '' '' ${VALUES[2]}
    echo "</td>"
    echo "</tr>"

    echo "<tr>"
    echo "<td width=${left}%>File Name</td>"
    echo "<td width=${right}%><input id='filename' name='filename' type='text' size='32' maxlength='128' value='${VALUES[3]}' onblur=\"checkPrintable( 'filename' )\" onmouseout=\"checkPrintable( 'filename' )\"></td>"
    echo "</tr>"

    echo "</table>"
    echo "</div>"

    echo "<div style='clear:left;'></div>"
    show-do enabled hidden
    show-form-end

    echo "<div style='clear:left;'></div>"
    echo "<br /><div class='table-title'>The installed SSL object</div>"
    echo "<div><table><tr><td><div id='sslcert' class='with-border'></div></td></tr></table></div>"

    echo "</div>"

    call-js-function "ajaxpage( '/${GUI_DIR_NAME}/authenticate-ldap-certificate-print.${GUI_EXT_NAME}', 'sslcert' );"
}

# Main()

show-authenticate-ldap-cert-form
