#!/bin/bash

############################################################################
#
# MODULE:       GUI
# AUTHOR(S):    CacheGuard Development Team
# COPYRIGHT:    (C) 2009-2020 by CacheGuard Technologies Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
###########################################################################

show-ca-component-list()
{
    local in_component=${1}
    local component selected

    for component in certificate key
    do
	if test ${component} == "${in_component}" ; then
	    selected=' selected'
	else
	    unset selected
	fi
	echo -n "<option value='${component}'${selected}>${component}</option>"
    done
}

show-ca-component()
{
    test -n "${1}" || return 1
    test -n "${2}" || return 2
    local component_id=${1}
    local content_id=${2}

    echo "<div style='clear:left;'></div><br />"
    echo "<div class='table-title'>The TLS object</div>"
    echo "<div id='${content_id}'></div>"

    call-js-function "printTLS( '/${GUI_DIR_NAME}/tls-print.${GUI_EXT_NAME}?CA', '${component_id}', '${content_id}', 'ca' );"
}

show-ca-manage-form()
{
    local component_id="ca_component"
    local content_id="ca_content"

    local state
    local width
    itemWidth[0]=30
    itemWidth[1]=70
    
    test -n "${CURRENT_ACCESS_FILE_LIST}" || state=disabled

    itemTitle[0]="CA Link"
    itemTitle[1]="CA Component"
    itemTitle[2]="Operation"
    itemTitle[3]="Protocol"
    itemTitle[4]="File Server"
    itemTitle[5]="File Name"

    itemID[0]="ca_links"
    itemID[1]="${component_id}"
    itemID[2]="operation"
    itemID[3]="protocol"
    itemID[4]="server"
    itemID[5]="filename"

    local web_ip=$(get-web-ip cur)

    blankItemContent[0]="<a href='http://${web_ip}' target='_blank'>${web_ip}</a> (available from the internal interface)"
    blankItemContent[1]="$(show-ca-component-list ${VALUES[0]})"
    blankItemContent[2]="$(show-file-operation ${VALUES[1]})"
    blankItemContent[3]="$(show-file-protocol1 ${VALUES[2]:1})"
    blankItemContent[4]="$(show-file-servers1 '' ${VALUES[3]})"
    blankItemContent[5]="type='text' size='48' maxlength='128' value='${VALUES[4]}'"

    checkItem[5]=printable

    itemForm[0]="text"
    itemForm[1]="select"
    itemForm[2]="select"
    itemForm[3]="select"
    itemForm[4]="select"
    
    itemFormSelectCB[1]="printTLS( '/${GUI_DIR_NAME}/tls-print.${GUI_EXT_NAME}?CA', '${component_id}', '${content_id}', 'ca' );"

    shortcutMenuItem[0]="access-file"
    shortcutMenuItem[1]="password-file"
    shortcutMenuTitle[0]="File Servers"
    shortcutMenuTitle[1]="Accounts"

    show-title "Load/Save The system CA Certificate" "${state}" "access admin password sslmediate tls"
    show-shortcuts-menu
    show-form "${width}" "${state}" "show-ca-component ${component_id} ${content_id}"
}

# Main()

show-ca-manage-form "${@}"
