#!/bin/bash

############################################################################
#
# MODULE:       GUI
# AUTHOR(S):    CacheGuard Development Team
# COPYRIGHT:    (C) 2009-2020 by CacheGuard Technologies Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
###########################################################################

print-revoke-reasons()
{
    echo -n "active keyCompromise CACompromise affiliationChanged superseded cessationOfOperation unspecified"
}

show-rweb-tls()
{
    local get_args=${1}
    local page_ref=$(get-arg-value "${get_args}" page)

    local width=500
    local state id file tag revoke generate

    itemWidth[0]=5
    itemWidth[1]=50
    itemWidth[2]=40
    itemWidth[3]=5

    itemTitle[0]=""
    itemTitle[1]="Identifier"
    itemTitle[2]="Revoke Status"
    itemTitle[3]="(Re)Gen?"

    itemForm[2]="select"
    itemForm[3]="state"
    
    itemID[0]="TLS"
    itemID[1]="tls"
    itemID[2]="status"
    itemID[3]="generate"
    
    blankItemContent[0]=""
    blankItemContent[1]="type='text' size='${MAX_NAME_LEN}' maxlength='${MAX_NAME_LEN}'"
    blankItemContent[2]=$(print-revoke-reasons)
    blankItemContent[3]="type='checkbox' checked"
    
    checkItem[1]=tls

    editColumnPage[0]="tls-client-save"
    editColumnTitle[0]="Save"
    
    unset listContent

    cd ${CLIENT_SSL_DIR}

    local all=$(ls -1d  *.cur *.new 2> /dev/null)

    for file in ${all}
    do
	id=${file%\.*}
	test ! -f ${id}.2del || continue
	tag=${file/*\.}
	if test -f ${id}.2rev ; then
	    revoke=$(cat ${id}.2rev 2> /dev/null)
	elif test -f ${id}.revoked ; then
	    revoke=$(cat ${id}.revoked 2> /dev/null)
	else
	    revoke='active'
	fi

	case ${tag} in
	    cur)
		if test -f ${id}.new ; then
		    generate=on
		else
		    generate=off
		fi
		listContent="${listContent} ${id} ${revoke} ${generate}"
		;;
	    new)
		test -d ${id}.cur || listContent="${listContent} ${id} ${revoke} on"
		;;
	    *)
		;;
	esac
    done

    listContent="${listContent:1}"
    listContentStep=3

    test -n "${listContent}" || state=disabled

    show-title "Manage Client TLS" "${state}" "tls rweb admin"
    show-list-form ${USERS_NB} ${width} "${page_ref}"
}

# Main()

show-rweb-tls "${@}"
